﻿//
// Parago Media GmbH & Co. KG, Jürgen Bäurle (jbaurle@parago.de)
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED 
// TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF 
// CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
// DEALINGS IN THE SOFTWARE.
//

using System;
using System.Collections.Generic;
using DotLiquid;

namespace SP2010TemplateEngine
{
	internal class TemplateManager
	{
		public Dictionary<string, Template> Templates { get; protected set; }

		public TemplateManager()
		{
			Templates = new Dictionary<string, Template>();
		}

		public void AddTemplate(string name, string template)
		{
			if(string.IsNullOrEmpty(name))
				throw new ArgumentNullException("name");
			if(string.IsNullOrEmpty(template))
				throw new ArgumentNullException("template");

			if(Templates.ContainsKey(name))
				Templates[name] = Template.Parse(template);
			else
				Templates.Add(name, Template.Parse(template));
		}

		public void RegisterTag<T>(string tagName) where T : Tag, new()
		{
			Template.RegisterTag<T>(tagName);
		}

		public void RegisterFilter(Type type)
		{
			Template.RegisterFilter(type);
		}

		public string Render(string nameOrTemplate, IDictionary<string, object> values)
		{
			Template template;

			if(Templates.ContainsKey(nameOrTemplate))
				template = Templates[nameOrTemplate];
			else
				template = Template.Parse(nameOrTemplate);

			SharePointDrop sp = new SharePointDrop();

			if(values != null)
			{
				foreach(KeyValuePair<string, object> kvp in values)
					sp.AddValue(kvp.Key, kvp.Value);
			}

			return template.Render(new RenderParameters { LocalVariables = Hash.FromAnonymousObject(new { SP = sp }), RethrowErrors = true });
		}
	}
}
